UiPath Documentation
automation-suite
2022.10
false
Guía de instalación de Automation Suite
Importante :
Este contenido se ha localizado parcialmente a partir de un sistema de traducción automática. La localización de contenidos recién publicados puede tardar entre una y dos semanas en estar disponible.

parámetros de install-uipath.sh

El instalador manual install-uipath.sh te permite personalizar la experiencia de instalación sin ejecutar el instalador interactivo (installUiPathAS.sh).

Aunque el instalador manual es adecuado para escenarios avanzados, las plantillas de implementación y el instalador interactivo siguen siendo las opciones recomendadas.

The install-uipath.sh installer is available in sf-installer.zip. For download instructions, see Downloading installation packages.

Parámetros requeridos​

--input -i <string>​

Especifica el archivo .json de entrada.

input.json refers to the cluster_config.json that defines the parameters, settings, and preferences applied to the UiPath® services deployed via Automation Suite. You need to update this file to change the defaults and use any advanced configuration for your cluster. For details, refer to Manual: Advanced installation experience.

--output -o <string>​

Especifica el archivo .json de salida.

output.json se refiere al archivo de salida del instalador manual.

Parámetros opcionales​

--install-kubernetes -k​

Instala el clúster de Kubernetes.

--join-node -j <server|agent>​

Se utiliza solo con -k. Determina el tipo de nodo que se unirá a un clúster existente. Valores permitidos: <server|agent>.

--install-fabric -f​

Instala los componentes de fábrica.

--install-services -s​

Instala los servicios de UiPath.

--install-all -a​

Ejecuta todos los instaladores por orden. Si no se selecciona expresamente ninguna instalación, –install-all estará implícita.

--install-type <online|offline>​

Especifica el tipo de instalación. Es online de forma predeterminada. No se puede establecer online junto con –offline-bundle.

--offline-bundle <string>​

Especifica la ruta al paquete sin conexión. Indica que el método de instalación es tarball.

--offline-tmp-folder <string>​

Marcador opcional que puede utilizarse con --offline-bundle o --optional-offline-bundle. Especifica el directorio principal para la carpeta de instalación sin conexión temporal. Es /tmp de forma predeterminada.

--optional-offline-bundle <string>​

Especifica la ruta al paquete sin conexión opcional.

--pre-reqs -p​

Comprueba los requisitos previos. Al utilizar este marcador, no se pueden aprobar otros marcadores.

--install-offline-prereqs​

Se utiliza con el método de instalación tarball y realiza la instalación de todos los requisitos previos.

--skip-packages-install​

Omite la instalación de los requisitos previos durante el método de instalación en línea. De manera predeterminada, se instalan los requisitos previos.

--upgrade -u​

Actualiza un clúster existente de Automation Suite.

--kubeconfig <string>​

Especifica la ruta al archivo kubeconfig. Cuando falta este marcador, el valor predeterminado es /etc/rancher/rke2/rke2.yaml.

--backup -b​

Copia de seguridad del clúster.

--restore -r​

Restaurar el clúster.

--restore-volume​

Restaura el volumen.

--disable-backup​

Deshabilitar la copia de seguridad.

Ejecutar en modo de depuración.

Muestra la ayuda.

--accept-license-agreement​

Marcador obligatorio para aceptar el acuerdo de licencia.

Instale Cilium CNI (Interfaz de red de contenedores) para reemplazar el Canal predeterminado. Solo se utiliza durante la actualización. No puede usarlo con ningún marcador de instalación.

--skip-pre-reqs​

Omitir las comprobaciones de requisitos previos durante la instalación. Tenga en cuenta que no puede omitir la validación del paquete RPM.

--one-time-manual-backup​

Activar la copia de seguridad manual y desactivarla tras su finalización.

-m|--machines <comma separated machine's IP>​

Especifique las máquinas de destino para la instalación. Proporcione direcciones IP separadas por comas o nombres de host de todas las máquinas.

--compare-config​

Compare el archivo de configuración actual con el estado del clúster. Compara el archivo input.json con la configuración actual del clúster.

--skip-compare-config​

Omitir compara la configuración actual con el estado del clúster.

Ejemplos​

  • Instale los componentes del clúster Kubernetes en la máquina virtual en la que se ejecuta, utilizando el método de instalación en línea.

    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement
    
  • Instale los componentes de Kubernetes en la máquina virtual en la que se ejecuta y únala al clúster existente como servidor, utilizando el método de instalación en línea.

    install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement
    
  • Realice la instalación completa en la máquina virtual actual, utilizando el método de instalación en línea. Incluye los componentes del clúster de Kubernetes, Fabric y los servicios de Uipath.

    install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement
    
  • Realice la instalación completa en la máquina virtual actual, utilizando el método de instalación en línea. Esta vez, omita la instalación de los requisitos previos.

    install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement
    
  • Realice la instalación del clúster de Kubernetes, utilizando el método de instalación tarball. Además, una el nodo al clúster existente e instale todos los requisitos previos sin conexión.

    install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement --install-offline-prereqs
    install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement --install-offline-prereqs
    
  • Asimismo, una el nodo al clúster existente e instale todos los requisitos previos sin conexión.

    install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement
    
  • Ejecute el instalador para realizar una instalación sin conexión, pero sin cargar los artefactos.

    install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement
    
  • Ejecuta el instalador omitiendo la comprobación de prerrequisitos

    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
    

¿Te ha resultado útil esta página?

Conectar

¿Necesita ayuda? Soporte

¿Quiere aprender? UiPath Academy

¿Tiene alguna pregunta? Foro de UiPath

Manténgase actualizado